#
# spec file for package unrar
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# majorversion should match the major version number.
%define majorversion 5
%define libsuffix 5_0_10

Name:           unrar
Version:        5.0.10
Release:        38.2
License:        SUSE-NonFree
Summary:        A program to extract, test, and view RAR archives
Url:            http://www.rarlab.com
Group:          Productivity/Archiving/Compression
Source0:        http://www.rarlab.com/rar/%{name}src-%{version}.tar.gz
Source1:        unrar.1
Patch1:         unrarsrc-3.9-types.patch
Patch2:         unrarsrc-5.0.5-soname.patch
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The unRAR utility is a freeware program distributed with source code
and developed for extracting, testing, and viewing the contents of
archives created with the RAR archiver.

%package -n libunrar%{libsuffix}

Summary:        Decompress library for RAR archives
Group:          System/Libraries

%description -n libunrar%{libsuffix}
The libunrar library allows programs linking against it to decompress
existing RAR v3 archives.

%package -n libunrar-devel
Summary:        Development files for libunrar
Group:          Development/Libraries/C and C++
Requires:       libunrar%{libsuffix} = %{version}

%description -n libunrar-devel
The libunrar-devel package contains libraries and header files for
developing applications that use libunrar.

%prep
%setup -q -n %{name}
%patch1
%patch2 -p1
sed -i 's/\r$//' *.txt

%build
make %{?_smp_mflags} -f makefile CXXFLAGS="%{optflags} \
    -fPIC -fno-strict-aliasing" STRIP=true
#bnc#693890
rm -f *.o
make %{?_smp_mflags} -f makefile lib libversion=%{version} \
    CXXFLAGS="%{optflags} -fPIC -fno-strict-aliasing" STRIP=true

%install
install -Dm 0755 unrar %{buildroot}%{_bindir}/unrar
install -Dm 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/unrar.1
install -Dm 0755 libunrar.so.%{version} \
    %{buildroot}%{_libdir}/libunrar.so.%{version}
install -Dm 0644 dll.hpp %{buildroot}/%{_includedir}/unrar/dll.hpp
ln -s libunrar.so.%{version} \
    %{buildroot}%{_libdir}/libunrar.so.%{majorversion}
ln -s libunrar.so.%{majorversion} %{buildroot}%{_libdir}/libunrar.so

%post -n libunrar%{libsuffix} -p /sbin/ldconfig

%postun -n libunrar%{libsuffix} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc acknow.txt license.txt readme.txt
%{_bindir}/unrar
%doc %{_mandir}/man1/unrar.1*

%files -n libunrar%{libsuffix}
%defattr(-,root,root)
%doc license.txt
%{_libdir}/*.so.%{majorversion}*

%files -n libunrar-devel
%defattr(-,root,root)
%doc acknow.txt license.txt readme.txt
%{_includedir}/*
%{_libdir}/*.so

%changelog
* Sun Aug  4 2013 lazy.kent@opensuse.org
- Update to 5.0.10.
  * Added missing makefile.
* Sun Aug  4 2013 lazy.kent@opensuse.org
- Update to 5.0.9.
  * No changelog available.
- Add acknow.txt to docs.
- Don't install readme.txt to the libunrar package.
- Temporarily use the makefile file from the previous version
  (missing in the source).
* Sun Jul 14 2013 lazy.kent@opensuse.org
- Update to 5.0.8.
  * No changes announced for unrar.
* Fri Jun 28 2013 idonmez@suse.com
- Update to 5.0.7
  * No changelog available
* Wed Jun 12 2013 idonmez@suse.com
- Update to 5.0.6
  * No changelog available
- Drop unrarsrc-4.2.4-gcc.patch, not needed anymore
* Tue May 28 2013 lazy.kent@opensuse.org
- Update to 5.0.5.
  * Support new RAR 5.0 archiving format.
  * 'v' and 'l' commands display archived file names in the end of
    line, not in that beginning as before. Also some fields
    previously available in 'l' and 'v' output are now shown only
    by 'lt' and 'vt'.
    'vt' and 'lt' commands provide the detailed multiline
    information for every archived file.
    'vta' and 'lta' also include service headers into list.
- Drop unrarsrc-3.9-variablesize.patch and
  unrar-4.2.4-no_return.patch (fixed upstream).
- Update unrarsrc-*-soname.patch.
- Disable unrarsrc-4.2.4-gcc.patch (until anyone confirms we really
  need it).
- Clean up "make" string (remove dupes provided by "optflags"
  macro).
- Correct libunrar Summary (remove v3).
- Update manual page.
* Fri Oct 19 2012 cfarrell@suse.com
- license update: SUSE-NonFree
  The description of SUSE-Permissive on the spreadsheet linked from
  license.opensuse.org would imply that such a licensed software would be
  suitable for Factory. For unrar this is clearly not the case - hence
  SUSE-NonFree
* Fri Oct 12 2012 lazy.kent@opensuse.org
- Update to 4.2.4.
  * No changelog provided.
- Add unrar-4.2.4-no_return.patch: fix no-return-in-nonvoid-function
  error.
- Change License tag: SUSE-Permissive.
- Use full URL as a source.
- Update "unrarsrc-*-gcc" and "unrarsrc-*-soname" patches.
- Correct libunrar Group: System/Libraries.
- Remove Provides: libunrar3_9_10-devel (no dependent packages
  found).
- Update man page.
- Mark man as doc.
- Clean up and formatting spec.
* Mon May 16 2011 puzel@novell.com
- use correct defines for building the library (bnc#693890)
* Wed Jan  5 2011 davejplater@gmail.com
- Update to 4.0.4 and remade updated man page with help2man
- Upstream changes :
  * previous beta versions could truncate some of files,
  extracted from ISO 9660 archives.
  * Version 4.00 beta 3
  * Now switch -ep3 converts not only disk letters, but also UNC paths.
  So \\server\share will be converted to __server\share when archiving
  and restored to the original \\server\share when extracting with -ep3.
  * previous beta could fail to unpack self-extracting and multivolume
  CAB archives;
  * "Create a new folder" command always created new folders
  in the root archive folder;
  * "Remove redundant folders from extraction path" option did not work;
  * previous beta crashed when displaying archive comments
  with ANSI escape sequences;
  * switches -cl and -cu did not work.
  * Version 4.00 beta 2
  * If you enabled "Use for all archives" option when entering the default
  password (Ctrl+P) and specified the empty password, extract and test
  commands will skip all encrypted archives.
  * Version 4.00 beta 1
  * RAR decompression speed is improved. Depending on data type,
  decompression can be up to 30%% faster than in previous versions.
  Both the general RAR algorithm and most of special RAR multimedia
  methods benefit from this improvement. The only module of RAR
  algorithm, which is not affected, is "Text compression" method.
  * UDF support is upgraded to UDF 2.50 revision. It makes possible
  to unpack most of Blu-ray ISO files;
  * Changes in -x switch syntax. Now you can specify a wildcard
  exclusion mask for folders. Such mask must have the trailing '\'
  character, like -x*tmp*\ or -x*\temp\
  * New error code 10 ("no files") is added to list of error codes
  returned in command line mode by RAR and WinRAR. This new code
  can be returned by archive, extract, delete and repair commands.
  It means that RAR did not find any files matched the specified
  file or archive mask.
  * Now switch -ep3 converts not only disk letters, but also UNC paths.
  So \\server\share will be converted to __server\share when archiving
  and restored to the original \\server\share when extracting with -ep3.
  * renaming a file in archive could also rename all other files
  with the same name in other folders of the same archive;
  * previous versions displayed the wrong total packed size
  in "Info" command for multivolume CAB archives;
- See "http://www.rarlab.com/rarnew.htm" for more details
* Wed Aug 18 2010 puzel@novell.com
- update to 3.9.10
  * no changelog available
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Jun 22 2009 mseben@suse.cz
- added libunrar* and libunrar*-devel subpackage bnc#513804
- added man page from debian
- updated to 3.9.4
  * no changelog available
* Thu Jan  8 2009 mseben@suse.cz
- update to 3.8.5
  * no changelog available
* Fri Jul 18 2008 lmichnovic@suse.cz
- update to 3.8.2 beta
  * no changelog available
- obsoletes *strcmp.patch
* Mon Nov 26 2007 lmichnovic@suse.cz
- update to 3.7.8 beta
  * RAR can close a corrupt encrypted archive
  * fix for CVE-2007-3726, obsoletes patch
* Tue Jul 17 2007 lmichnovic@suse.cz
- fix for crash on corrupted file (CVE-2007-3726.patch) [#291702]
* Fri Jun  8 2007 lmichnovic@suse.cz
- update to 3.7.6 final
  * minor code rework
  * fixed CR-LF in file with License
* Mon Mar 12 2007 lmichnovic@suse.cz
- update to version 3.7.4 beta
  * minor code rework
* Fri Feb 23 2007 lmichnovic@suse.cz
- corrected typo in code (variablesize.patch)
* Tue Feb 13 2007 lmichnovic@suse.cz
- update to version 3.7.3 beta
  * rewritten work with memory in VM
* Tue Jan 23 2007 lmichnovic@suse.cz
- update to version 3.7.2 beta
  * Stack overflow vulnerability has been corrected in password
    processing module of console RAR and UnRAR.
  * New switch -sc[objects] allowing to select character sets for
    archive comments and list files. It replaces -fcu switch, which
    was removed from list of supported switches. Now you need to
    specify -scuc instead of -fcu to use Unicode comments.
    Unlike -fcu, -sc also supports OEM and ANSI charset.
  * workaround for one occasional bug with unicode
* Sun Dec 17 2006 schwab@suse.de
- Fix last change.
* Fri Dec 15 2006 lmichnovic@suse.cz
- corrected and readded reverted *strcmp.patch
* Fri Dec 15 2006 mmarek@suse.cz
- revert last change (it worked previously and the strcmp patch
  breaks --help output)
* Wed Dec 13 2006 lmichnovic@suse.cz
- fixed string comparing (*strcmp.patch)
* Fri Jul 14 2006 lmichnovic@suse.cz
- update to version 3.60
  - non beta version
* Fri Jul 14 2006 lmichnovic@suse.cz
- update to version 3.60 beta 7
  - in unrar changed only version, version changed due to fix in rar
* Mon Jul 10 2006 lmichnovic@suse.cz
- upgrade to version 3.60 beta 6
  - no changelog available
* Wed Jun 21 2006 lmichnovic@suse.cz
- upgrade to version 3.60 beta 5
  - no changelog available
* Tue Jun 13 2006 lmichnovic@suse.cz
- upgrade to version 3.6.4
  - no changelog available
- change the numbering to 3.6.0.4 because it is 3.60 beta 4
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Thu Jan 12 2006 lmichnovic@suse.cz
- added -fstack-protector into CXXFLAGS
* Mon Nov 21 2005 lmichnovic@suse.cz
- added no-strict-aliasing option for compiling
* Tue Oct 11 2005 lmichnovic@suse.cz
- update to version 3.5.4
* Fri Sep 16 2005 lmichnovic@suse.cz
- update to version 3.5.3
* Tue Aug  2 2005 mjancar@suse.cz
- update ro 3.5.2
* Tue Apr 19 2005 mjancar@suse.cz
- fix for gcc 4.0
* Thu Feb 17 2005 mjancar@suse.cz
- update to 3.4.3
* Fri Aug  6 2004 mjancar@suse.cz
- update to 3.4.2
* Fri Feb 27 2004 mjancar@suse.cz
- update to 3.3.6
* Tue Oct 21 2003 mjancar@suse.cz
- update to 3.2.3
* Thu Jul 24 2003 mjancar@suse.cz
- update to 3.2.2
* Wed May 14 2003 mjancar@suse.cz
- update to version 3.2.1
* Tue May  6 2003 ro@suse.de
- fix build with latest gcc
* Mon Feb 17 2003 vbobek@suse.cz
- updated to version 3.1.3
- removed obsolete patch for CFLAGS
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue May 21 2002 nadvornik@suse.cz
- updated to 3.00 [bug #16183]
* Thu Apr 18 2002 stepan@suse.de
- update to 2.71, drop 64bit patch
* Wed Feb 20 2002 stepan@suse.de
- Fix archive corruption on 64bit systems. Linux GNU systems
  always have 32bit int, so using int instead of long for
  UDWORD.
* Mon Apr 17 2000 nadvornik@suse.cz
- added BuildRoot
* Thu Feb 17 2000 grimmer@suse.de
- use full URL to source archive
- use version macro
- spec file cleanups
- added Group tag
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul  5 1999 grimmer@suse.de
- initial package created (Version 2.50)
